#include <linux/input.h>

#define EV_MAP( N ) [ N ] = #N

static char *EV_NAME[EV_MAX] = {
	EV_MAP( EV_SYN ),
	EV_MAP( EV_KEY ),
	EV_MAP( EV_REL ),
	EV_MAP( EV_ABS ),
	EV_MAP( EV_MSC ),
	EV_MAP( EV_SW ),
	EV_MAP( EV_LED ),
	EV_MAP( EV_SND ),
	EV_MAP( EV_REP ),
	EV_MAP( EV_FF ),
	EV_MAP( EV_PWR ),
	EV_MAP( EV_FF_STATUS ),
};

static char *KEY_NAME[KEY_MAX] = {
	EV_MAP( KEY_RESERVED ),
	EV_MAP( KEY_ESC ),
	EV_MAP( KEY_1 ),
	EV_MAP( KEY_2 ),
	EV_MAP( KEY_3 ),
	EV_MAP( KEY_4 ),
	EV_MAP( KEY_5 ),
	EV_MAP( KEY_6 ),
	EV_MAP( KEY_7 ),
	EV_MAP( KEY_8 ),
	EV_MAP( KEY_9 ),
	EV_MAP( KEY_0 ),
	EV_MAP( KEY_MINUS ),
	EV_MAP( KEY_EQUAL ),
	EV_MAP( KEY_BACKSPACE ),
	EV_MAP( KEY_TAB ),
	EV_MAP( KEY_Q ),
	EV_MAP( KEY_W ),
	EV_MAP( KEY_E ),
	EV_MAP( KEY_R ),
	EV_MAP( KEY_T ),
	EV_MAP( KEY_Y ),
	EV_MAP( KEY_U ),
	EV_MAP( KEY_I ),
	EV_MAP( KEY_O ),
	EV_MAP( KEY_P ),
	EV_MAP( KEY_LEFTBRACE ),
	EV_MAP( KEY_RIGHTBRACE ),
	EV_MAP( KEY_ENTER ),
	EV_MAP( KEY_LEFTCTRL ),
	EV_MAP( KEY_A ),
	EV_MAP( KEY_S ),
	EV_MAP( KEY_D ),
	EV_MAP( KEY_F ),
	EV_MAP( KEY_G ),
	EV_MAP( KEY_H ),
	EV_MAP( KEY_J ),
	EV_MAP( KEY_K ),
	EV_MAP( KEY_L ),
	EV_MAP( KEY_SEMICOLON ),
	EV_MAP( KEY_APOSTROPHE ),
	EV_MAP( KEY_GRAVE ),
	EV_MAP( KEY_LEFTSHIFT ),
	EV_MAP( KEY_BACKSLASH ),
	EV_MAP( KEY_Z ),
	EV_MAP( KEY_X ),
	EV_MAP( KEY_C ),
	EV_MAP( KEY_V ),
	EV_MAP( KEY_B ),
	EV_MAP( KEY_N ),
	EV_MAP( KEY_M ),
	EV_MAP( KEY_COMMA ),
	EV_MAP( KEY_DOT ),
	EV_MAP( KEY_SLASH ),
	EV_MAP( KEY_RIGHTSHIFT ),
	EV_MAP( KEY_KPASTERISK ),
	EV_MAP( KEY_LEFTALT ),
	EV_MAP( KEY_SPACE ),
	EV_MAP( KEY_CAPSLOCK ),
	EV_MAP( KEY_F1 ),
	EV_MAP( KEY_F2 ),
	EV_MAP( KEY_F3 ),
	EV_MAP( KEY_F4 ),
	EV_MAP( KEY_F5 ),
	EV_MAP( KEY_F6 ),
	EV_MAP( KEY_F7 ),
	EV_MAP( KEY_F8 ),
	EV_MAP( KEY_F9 ),
	EV_MAP( KEY_F10 ),
	EV_MAP( KEY_NUMLOCK ),
	EV_MAP( KEY_SCROLLLOCK ),
	EV_MAP( KEY_KP7 ),
	EV_MAP( KEY_KP8 ),
	EV_MAP( KEY_KP9 ),
	EV_MAP( KEY_KPMINUS ),
	EV_MAP( KEY_KP4 ),
	EV_MAP( KEY_KP5 ),
	EV_MAP( KEY_KP6 ),
	EV_MAP( KEY_KPPLUS ),
	EV_MAP( KEY_KP1 ),
	EV_MAP( KEY_KP2 ),
	EV_MAP( KEY_KP3 ),
	EV_MAP( KEY_KP0 ),
	EV_MAP( KEY_KPDOT ),
	EV_MAP( KEY_ZENKAKUHANKAKU ),
	EV_MAP( KEY_102ND ),
	EV_MAP( KEY_F11 ),
	EV_MAP( KEY_F12 ),
	EV_MAP( KEY_RO ),
	EV_MAP( KEY_KATAKANA ),
	EV_MAP( KEY_HIRAGANA ),
	EV_MAP( KEY_HENKAN ),
	EV_MAP( KEY_KATAKANAHIRAGANA ),
	EV_MAP( KEY_MUHENKAN ),
	EV_MAP( KEY_KPJPCOMMA ),
	EV_MAP( KEY_KPENTER ),
	EV_MAP( KEY_RIGHTCTRL ),
	EV_MAP( KEY_KPSLASH ),
	EV_MAP( KEY_SYSRQ ),
	EV_MAP( KEY_RIGHTALT ),
	EV_MAP( KEY_LINEFEED ),
	EV_MAP( KEY_HOME ),
	EV_MAP( KEY_UP ),
	EV_MAP( KEY_PAGEUP ),
	EV_MAP( KEY_LEFT ),
	EV_MAP( KEY_RIGHT ),
	EV_MAP( KEY_END ),
	EV_MAP( KEY_DOWN ),
	EV_MAP( KEY_PAGEDOWN ),
	EV_MAP( KEY_INSERT ),
	EV_MAP( KEY_DELETE ),
	EV_MAP( KEY_MACRO ),
	EV_MAP( KEY_MUTE ),
	EV_MAP( KEY_VOLUMEDOWN ),
	EV_MAP( KEY_VOLUMEUP ),
	EV_MAP( KEY_POWER ),
	EV_MAP( KEY_KPEQUAL ),
	EV_MAP( KEY_KPPLUSMINUS ),
	EV_MAP( KEY_PAUSE ),
	EV_MAP( KEY_SCALE ),
	EV_MAP( KEY_KPCOMMA ),
	EV_MAP( KEY_HANGEUL ),
	EV_MAP( KEY_HANGUEL ),
	EV_MAP( KEY_HANJA ),
	EV_MAP( KEY_YEN ),
	EV_MAP( KEY_LEFTMETA ),
	EV_MAP( KEY_RIGHTMETA ),
	EV_MAP( KEY_COMPOSE ),
	EV_MAP( KEY_STOP ),
	EV_MAP( KEY_AGAIN ),
	EV_MAP( KEY_PROPS ),
	EV_MAP( KEY_UNDO ),
	EV_MAP( KEY_FRONT ),
	EV_MAP( KEY_COPY ),
	EV_MAP( KEY_OPEN ),
	EV_MAP( KEY_PASTE ),
	EV_MAP( KEY_FIND ),
	EV_MAP( KEY_CUT ),
	EV_MAP( KEY_HELP ),
	EV_MAP( KEY_MENU ),
	EV_MAP( KEY_CALC ),
	EV_MAP( KEY_SETUP ),
	EV_MAP( KEY_SLEEP ),
	EV_MAP( KEY_WAKEUP ),
	EV_MAP( KEY_FILE ),
	EV_MAP( KEY_SENDFILE ),
	EV_MAP( KEY_DELETEFILE ),
	EV_MAP( KEY_XFER ),
	EV_MAP( KEY_PROG1 ),
	EV_MAP( KEY_PROG2 ),
	EV_MAP( KEY_WWW ),
	EV_MAP( KEY_MSDOS ),
	EV_MAP( KEY_COFFEE ),
	EV_MAP( KEY_SCREENLOCK ),
	EV_MAP( KEY_DIRECTION ),
	EV_MAP( KEY_CYCLEWINDOWS ),
	EV_MAP( KEY_MAIL ),
	EV_MAP( KEY_BOOKMARKS ),
	EV_MAP( KEY_COMPUTER ),
	EV_MAP( KEY_BACK ),
	EV_MAP( KEY_FORWARD ),
	EV_MAP( KEY_CLOSECD ),
	EV_MAP( KEY_EJECTCD ),
	EV_MAP( KEY_EJECTCLOSECD ),
	EV_MAP( KEY_NEXTSONG ),
	EV_MAP( KEY_PLAYPAUSE ),
	EV_MAP( KEY_PREVIOUSSONG ),
	EV_MAP( KEY_STOPCD ),
	EV_MAP( KEY_RECORD ),
	EV_MAP( KEY_REWIND ),
	EV_MAP( KEY_PHONE ),
	EV_MAP( KEY_ISO ),
	EV_MAP( KEY_CONFIG ),
	EV_MAP( KEY_HOMEPAGE ),
	EV_MAP( KEY_REFRESH ),
	EV_MAP( KEY_EXIT ),
	EV_MAP( KEY_MOVE ),
	EV_MAP( KEY_EDIT ),
	EV_MAP( KEY_SCROLLUP ),
	EV_MAP( KEY_SCROLLDOWN ),
	EV_MAP( KEY_KPLEFTPAREN ),
	EV_MAP( KEY_KPRIGHTPAREN ),
	EV_MAP( KEY_NEW ),
	EV_MAP( KEY_REDO ),
	EV_MAP( KEY_F13 ),
	EV_MAP( KEY_F14 ),
	EV_MAP( KEY_F15 ),
	EV_MAP( KEY_F16 ),
	EV_MAP( KEY_F17 ),
	EV_MAP( KEY_F18 ),
	EV_MAP( KEY_F19 ),
	EV_MAP( KEY_F20 ),
	EV_MAP( KEY_F21 ),
	EV_MAP( KEY_F22 ),
	EV_MAP( KEY_F23 ),
	EV_MAP( KEY_F24 ),
	EV_MAP( KEY_PLAYCD ),
	EV_MAP( KEY_PAUSECD ),
	EV_MAP( KEY_PROG3 ),
	EV_MAP( KEY_PROG4 ),
	EV_MAP( KEY_DASHBOARD ),
	EV_MAP( KEY_SUSPEND ),
	EV_MAP( KEY_CLOSE ),
	EV_MAP( KEY_PLAY ),
	EV_MAP( KEY_FASTFORWARD ),
	EV_MAP( KEY_BASSBOOST ),
	EV_MAP( KEY_PRINT ),
	EV_MAP( KEY_HP ),
	EV_MAP( KEY_CAMERA ),
	EV_MAP( KEY_SOUND ),
	EV_MAP( KEY_QUESTION ),
	EV_MAP( KEY_EMAIL ),
	EV_MAP( KEY_CHAT ),
	EV_MAP( KEY_SEARCH ),
	EV_MAP( KEY_CONNECT ),
	EV_MAP( KEY_FINANCE ),
	EV_MAP( KEY_SPORT ),
	EV_MAP( KEY_SHOP ),
	EV_MAP( KEY_ALTERASE ),
	EV_MAP( KEY_CANCEL ),
	EV_MAP( KEY_BRIGHTNESSDOWN ),
	EV_MAP( KEY_BRIGHTNESSUP ),
	EV_MAP( KEY_MEDIA ),
	EV_MAP( KEY_SWITCHVIDEOMODE ),
	EV_MAP( KEY_KBDILLUMTOGGLE ),
	EV_MAP( KEY_KBDILLUMDOWN ),
	EV_MAP( KEY_KBDILLUMUP ),
	EV_MAP( KEY_SEND ),
	EV_MAP( KEY_REPLY ),
	EV_MAP( KEY_FORWARDMAIL ),
	EV_MAP( KEY_SAVE ),
	EV_MAP( KEY_DOCUMENTS ),
	EV_MAP( KEY_BATTERY ),
	EV_MAP( KEY_BLUETOOTH ),
	EV_MAP( KEY_WLAN ),
	EV_MAP( KEY_UWB ),
	EV_MAP( KEY_UNKNOWN ),
	EV_MAP( KEY_VIDEO_NEXT ),
	EV_MAP( KEY_VIDEO_PREV ),
	EV_MAP( KEY_BRIGHTNESS_CYCLE ),
	EV_MAP( KEY_BRIGHTNESS_ZERO ),
	EV_MAP( KEY_DISPLAY_OFF ),
	EV_MAP( KEY_WIMAX ),
	EV_MAP( KEY_OK ),
	EV_MAP( KEY_SELECT ),
	EV_MAP( KEY_GOTO ),
	EV_MAP( KEY_CLEAR ),
	EV_MAP( KEY_POWER2 ),
	EV_MAP( KEY_OPTION ),
	EV_MAP( KEY_INFO ),
	EV_MAP( KEY_TIME ),
	EV_MAP( KEY_VENDOR ),
	EV_MAP( KEY_ARCHIVE ),
	EV_MAP( KEY_PROGRAM ),
	EV_MAP( KEY_CHANNEL ),
	EV_MAP( KEY_FAVORITES ),
	EV_MAP( KEY_EPG ),
	EV_MAP( KEY_PVR ),
	EV_MAP( KEY_MHP ),
	EV_MAP( KEY_LANGUAGE ),
	EV_MAP( KEY_TITLE ),
	EV_MAP( KEY_SUBTITLE ),
	EV_MAP( KEY_ANGLE ),
	EV_MAP( KEY_ZOOM ),
	EV_MAP( KEY_MODE ),
	EV_MAP( KEY_KEYBOARD ),
	EV_MAP( KEY_SCREEN ),
	EV_MAP( KEY_PC ),
	EV_MAP( KEY_TV ),
	EV_MAP( KEY_TV2 ),
	EV_MAP( KEY_VCR ),
	EV_MAP( KEY_VCR2 ),
	EV_MAP( KEY_SAT ),
	EV_MAP( KEY_SAT2 ),
	EV_MAP( KEY_CD ),
	EV_MAP( KEY_TAPE ),
	EV_MAP( KEY_RADIO ),
	EV_MAP( KEY_TUNER ),
	EV_MAP( KEY_PLAYER ),
	EV_MAP( KEY_TEXT ),
	EV_MAP( KEY_DVD ),
	EV_MAP( KEY_AUX ),
	EV_MAP( KEY_MP3 ),
	EV_MAP( KEY_AUDIO ),
	EV_MAP( KEY_VIDEO ),
	EV_MAP( KEY_DIRECTORY ),
	EV_MAP( KEY_LIST ),
	EV_MAP( KEY_MEMO ),
	EV_MAP( KEY_CALENDAR ),
	EV_MAP( KEY_RED ),
	EV_MAP( KEY_GREEN ),
	EV_MAP( KEY_YELLOW ),
	EV_MAP( KEY_BLUE ),
	EV_MAP( KEY_CHANNELUP ),
	EV_MAP( KEY_CHANNELDOWN ),
	EV_MAP( KEY_FIRST ),
	EV_MAP( KEY_LAST ),
	EV_MAP( KEY_AB ),
	EV_MAP( KEY_NEXT ),
	EV_MAP( KEY_RESTART ),
	EV_MAP( KEY_SLOW ),
	EV_MAP( KEY_SHUFFLE ),
	EV_MAP( KEY_BREAK ),
	EV_MAP( KEY_PREVIOUS ),
	EV_MAP( KEY_DIGITS ),
	EV_MAP( KEY_TEEN ),
	EV_MAP( KEY_TWEN ),
	EV_MAP( KEY_VIDEOPHONE ),
	EV_MAP( KEY_GAMES ),
	EV_MAP( KEY_ZOOMIN ),
	EV_MAP( KEY_ZOOMOUT ),
	EV_MAP( KEY_ZOOMRESET ),
	EV_MAP( KEY_WORDPROCESSOR ),
	EV_MAP( KEY_EDITOR ),
	EV_MAP( KEY_SPREADSHEET ),
	EV_MAP( KEY_GRAPHICSEDITOR ),
	EV_MAP( KEY_PRESENTATION ),
	EV_MAP( KEY_DATABASE ),
	EV_MAP( KEY_NEWS ),
	EV_MAP( KEY_VOICEMAIL ),
	EV_MAP( KEY_ADDRESSBOOK ),
	EV_MAP( KEY_MESSENGER ),
	EV_MAP( KEY_DISPLAYTOGGLE ),
	EV_MAP( KEY_SPELLCHECK ),
	EV_MAP( KEY_LOGOFF ),
	EV_MAP( KEY_DOLLAR ),
	EV_MAP( KEY_EURO ),
	EV_MAP( KEY_FRAMEBACK ),
	EV_MAP( KEY_FRAMEFORWARD ),
	EV_MAP( KEY_CONTEXT_MENU ),
	EV_MAP( KEY_MEDIA_REPEAT ),
	EV_MAP( KEY_DEL_EOL ),
	EV_MAP( KEY_DEL_EOS ),
	EV_MAP( KEY_INS_LINE ),
	EV_MAP( KEY_DEL_LINE ),
	EV_MAP( KEY_FN ),
	EV_MAP( KEY_FN_ESC ),
	EV_MAP( KEY_FN_F1 ),
	EV_MAP( KEY_FN_F2 ),
	EV_MAP( KEY_FN_F3 ),
	EV_MAP( KEY_FN_F4 ),
	EV_MAP( KEY_FN_F5 ),
	EV_MAP( KEY_FN_F6 ),
	EV_MAP( KEY_FN_F7 ),
	EV_MAP( KEY_FN_F8 ),
	EV_MAP( KEY_FN_F9 ),
	EV_MAP( KEY_FN_F10 ),
	EV_MAP( KEY_FN_F11 ),
	EV_MAP( KEY_FN_F12 ),
	EV_MAP( KEY_FN_1 ),
	EV_MAP( KEY_FN_2 ),
	EV_MAP( KEY_FN_D ),
	EV_MAP( KEY_FN_E ),
	EV_MAP( KEY_FN_F ),
	EV_MAP( KEY_FN_S ),
	EV_MAP( KEY_FN_B ),
	EV_MAP( KEY_BRL_DOT1 ),
	EV_MAP( KEY_BRL_DOT2 ),
	EV_MAP( KEY_BRL_DOT3 ),
	EV_MAP( KEY_BRL_DOT4 ),
	EV_MAP( KEY_BRL_DOT5 ),
	EV_MAP( KEY_BRL_DOT6 ),
	EV_MAP( KEY_BRL_DOT7 ),
	EV_MAP( KEY_BRL_DOT8 ),
	EV_MAP( KEY_BRL_DOT9 ),
	EV_MAP( KEY_BRL_DOT10 ),
	EV_MAP( KEY_NUMERIC_0 ),
	EV_MAP( KEY_NUMERIC_1 ),
	EV_MAP( KEY_NUMERIC_2 ),
	EV_MAP( KEY_NUMERIC_3 ),
	EV_MAP( KEY_NUMERIC_4 ),
	EV_MAP( KEY_NUMERIC_5 ),
	EV_MAP( KEY_NUMERIC_6 ),
	EV_MAP( KEY_NUMERIC_7 ),
	EV_MAP( KEY_NUMERIC_8 ),
	EV_MAP( KEY_NUMERIC_9 ),
	EV_MAP( KEY_NUMERIC_STAR ),
	EV_MAP( KEY_NUMERIC_POUND ),
	EV_MAP( KEY_MIN_INTERESTING ),
	EV_MAP( BTN_MISC ),
	EV_MAP( BTN_0 ),
	EV_MAP( BTN_1 ),
	EV_MAP( BTN_2 ),
	EV_MAP( BTN_3 ),
	EV_MAP( BTN_4 ),
	EV_MAP( BTN_5 ),
	EV_MAP( BTN_6 ),
	EV_MAP( BTN_7 ),
	EV_MAP( BTN_8 ),
	EV_MAP( BTN_9 ),
	EV_MAP( BTN_MOUSE ),
	EV_MAP( BTN_LEFT ),
	EV_MAP( BTN_RIGHT ),
	EV_MAP( BTN_MIDDLE ),
	EV_MAP( BTN_SIDE ),
	EV_MAP( BTN_EXTRA ),
	EV_MAP( BTN_FORWARD ),
	EV_MAP( BTN_BACK ),
	EV_MAP( BTN_TASK ),
	EV_MAP( BTN_JOYSTICK ),
	EV_MAP( BTN_TRIGGER ),
	EV_MAP( BTN_THUMB ),
	EV_MAP( BTN_THUMB2 ),
	EV_MAP( BTN_TOP ),
	EV_MAP( BTN_TOP2 ),
	EV_MAP( BTN_PINKIE ),
	EV_MAP( BTN_BASE ),
	EV_MAP( BTN_BASE2 ),
	EV_MAP( BTN_BASE3 ),
	EV_MAP( BTN_BASE4 ),
	EV_MAP( BTN_BASE5 ),
	EV_MAP( BTN_BASE6 ),
	EV_MAP( BTN_DEAD ),
	EV_MAP( BTN_GAMEPAD ),
	EV_MAP( BTN_A ),
	EV_MAP( BTN_B ),
	EV_MAP( BTN_C ),
	EV_MAP( BTN_X ),
	EV_MAP( BTN_Y ),
	EV_MAP( BTN_Z ),
	EV_MAP( BTN_TL ),
	EV_MAP( BTN_TR ),
	EV_MAP( BTN_TL2 ),
	EV_MAP( BTN_TR2 ),
	EV_MAP( BTN_SELECT ),
	EV_MAP( BTN_START ),
	EV_MAP( BTN_MODE ),
	EV_MAP( BTN_THUMBL ),
	EV_MAP( BTN_THUMBR ),
	EV_MAP( BTN_DIGI ),
	EV_MAP( BTN_TOOL_PEN ),
	EV_MAP( BTN_TOOL_RUBBER ),
	EV_MAP( BTN_TOOL_BRUSH ),
	EV_MAP( BTN_TOOL_PENCIL ),
	EV_MAP( BTN_TOOL_AIRBRUSH ),
	EV_MAP( BTN_TOOL_FINGER ),
	EV_MAP( BTN_TOOL_MOUSE ),
	EV_MAP( BTN_TOOL_LENS ),
	EV_MAP( BTN_TOUCH ),
	EV_MAP( BTN_STYLUS ),
	EV_MAP( BTN_STYLUS2 ),
	EV_MAP( BTN_TOOL_DOUBLETAP ),
	EV_MAP( BTN_TOOL_TRIPLETAP ),
	EV_MAP( BTN_TOOL_QUADTAP ),
	EV_MAP( BTN_WHEEL ),
	EV_MAP( BTN_GEAR_DOWN ),
	EV_MAP( BTN_GEAR_UP ),
};

static char *SW_NAME[SW_MAX] = {
	EV_MAP( SW_LID ),
	EV_MAP( SW_TABLET_MODE ),
	EV_MAP( SW_HEADPHONE_INSERT ),
	EV_MAP( SW_RFKILL_ALL ),
	EV_MAP( SW_MICROPHONE_INSERT ),
	EV_MAP( SW_DOCK ),
	EV_MAP( SW_LINEOUT_INSERT ),
	EV_MAP( SW_JACK_PHYSICAL_INSERT ),
	EV_MAP( SW_VIDEOOUT_INSERT ),
};
